@@ -25,8 +25,10 @@ from pipeline.api.eds import demo_eds_webplot_point_live, EdsClient, load_histor
 from pipeline import environment
 from pipeline.security_and_config import get_eds_api_credentials, get_external_api_credentials, get_eds_db_credentials, get_all_configured_urls, get_configurable_plant_name, init_security, CONFIG_PATH
 from pipeline.termux_setup import setup_termux_shortcut
+from pipeline.windows_setup import setup_windows_install, cleanup_windows_install
 from pipeline import helpers
 from pipeline.plotbuffer import PlotBuffer
+from pipeline.version_info import  PIP_PACKAGE_NAME, PIPELINE_VERSION, __version__, get_package_version
 #from pipeline.helpers import setup_logging
 
 # --- TERMUX SETUP HOOK ---
@@ -35,33 +37,17 @@ from pipeline.plotbuffer import PlotBuffer
 # ensures the shortcut file is only created once in the Termux environment.
 if environment.is_termux():
     setup_termux_shortcut()
+elif environment.is_windows():
+    setup_windows_install()
 
 # -- Versioning --
-CLI_APP_NAME = "pipeline"
-PIP_PACKAGE_NAME = "pipeline-eds"
 def print_version(value: bool):
     if value:
         try:
-            typer.secho(f"{CLI_APP_NAME} {PIPELINE_VERSION}",fg=typer.colors.GREEN, bold=True)
+            typer.secho(f"{PIP_PACKAGE_NAME} {PIPELINE_VERSION}",fg=typer.colors.GREEN, bold=True)
         except PackageNotFoundError:
             typer.echo("Version info not found")
         raise typer.Exit()
-try:
-    PIPELINE_VERSION = version(PIP_PACKAGE_NAME)
-    __version__ = version(PIP_PACKAGE_NAME)
-except PackageNotFoundError:
-    PIPELINE_VERSION = "unknown"
-
-try:
-    from importlib.metadata import version
-    __version__ = version(PIP_PACKAGE_NAME)
-except PackageNotFoundError:
-    # fallback if running from source
-    try:
-        with open(Path(__file__).parent / "VERSION") as f:
-            __version__ = f.read().strip()
-    except FileNotFoundError:
-        __version__ = "dev" 
 
 ### Pipeline CLI
 
@@ -387,6 +373,26 @@ def list_workspaces():
     for name in workspaces_list:
         typer.echo(f" - {name}")
 
+@app.command()
+def install(
+    uninstall: bool = typer.Option(False,"--uninstall","-u",help = "Remove the installation artifacts for the current operating system.")
+):
+    """
+    Windows: Uninstall the registry context-menu item, the launcher BAT, and the AppData folder
+    Termux: Remove the scripts from the .shortcuts/ folder.
+    """
+    if uninstall:
+        if environment.is_windows():
+            if typer.confirm("Are you sure you want to uninstall the registry context-menu item, the launcher BAT, and empty out the AppData folder?"):
+                cleanup_windows_install()
+        elif environment.is_termux():
+            pass
+    else:
+        if environment.is_windows():
+            setup_windows_install()
+        elif environment.is_termux():
+            setup_termux_shortcut()
+
 
 @app.command()
 def ping(
